==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/portal/kotlin/ConsoleWithLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.portal.kotlin

import com.pulumi.azurenative.portal.kotlin.outputs.ConsolePropertiesResponse
import com.pulumi.azurenative.portal.kotlin.outputs.ConsolePropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ConsoleWithLocation].
 */
@PulumiTagMarker
public class ConsoleWithLocationResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ConsoleWithLocationArgs = ConsoleWithLocationArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ConsoleWithLocationArgsBuilder.() -> Unit) {
        val builder = ConsoleWithLocationArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ConsoleWithLocation {
        val builtJavaResource =
            com.pulumi.azurenative.portal.ConsoleWithLocation(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ConsoleWithLocation(builtJavaResource)
    }
}

/**
 * Cloud shell console
 * Azure REST API version: 2018-10-01. Prior API version in Azure Native 1.x: 2018-10-01.
 * ## Example Usage
 * ### PutConsole
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var consoleWithLocation = new AzureNative.Portal.ConsoleWithLocation("consoleWithLocation", new()
 *     {
 *         ConsoleName = "default",
 *         Location = "eastus",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/portal/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := portal.NewConsoleWithLocation(ctx, "consoleWithLocation", &portal.ConsoleWithLocationArgs{
 * 			ConsoleName: pulumi.String("default"),
 * 			Location:    pulumi.String("eastus"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.portal.ConsoleWithLocation;
 * import com.pulumi.azurenative.portal.ConsoleWithLocationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var consoleWithLocation = new ConsoleWithLocation("consoleWithLocation", ConsoleWithLocationArgs.builder()
 *             .consoleName("default")
 *             .location("eastus")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:portal:ConsoleWithLocation myresource1 /providers/Microsoft.Portal/locations/{location}/consoles/{consoleName}
 * ```
 */
public class ConsoleWithLocation internal constructor(
    override val javaResource: com.pulumi.azurenative.portal.ConsoleWithLocation,
) : KotlinCustomResource(javaResource, ConsoleWithLocationMapper) {
    /**
     * Cloud shell console properties.
     */
    public val properties: Output<ConsolePropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })
}

public object ConsoleWithLocationMapper : ResourceMapper<ConsoleWithLocation> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.portal.ConsoleWithLocation::class == javaResource::class

    override fun map(javaResource: Resource): ConsoleWithLocation = ConsoleWithLocation(
        javaResource
            as com.pulumi.azurenative.portal.ConsoleWithLocation,
    )
}

/**
 * @see [ConsoleWithLocation].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ConsoleWithLocation].
 */
public suspend fun consoleWithLocation(
    name: String,
    block: suspend ConsoleWithLocationResourceBuilder.() -> Unit,
): ConsoleWithLocation {
    val builder = ConsoleWithLocationResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ConsoleWithLocation].
 * @param name The _unique_ name of the resulting resource.
 */
public fun consoleWithLocation(name: String): ConsoleWithLocation {
    val builder = ConsoleWithLocationResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/portal/kotlin/ConsoleWithLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.portal.kotlin

import com.pulumi.azurenative.portal.kotlin.outputs.ConsolePropertiesResponse
import com.pulumi.azurenative.portal.kotlin.outputs.ConsolePropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ConsoleWithLocation].
 */
@PulumiTagMarker
public class ConsoleWithLocationResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ConsoleWithLocationArgs = ConsoleWithLocationArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ConsoleWithLocationArgsBuilder.() -> Unit) {
        val builder = ConsoleWithLocationArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ConsoleWithLocation {
        val builtJavaResource =
            com.pulumi.azurenative.portal.ConsoleWithLocation(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ConsoleWithLocation(builtJavaResource)
    }
}

/**
 * Cloud shell console
 * Azure REST API version: 2018-10-01. Prior API version in Azure Native 1.x: 2018-10-01.
 * ## Example Usage
 * ### PutConsole
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var consoleWithLocation = new AzureNative.Portal.ConsoleWithLocation("consoleWithLocation", new()
 *     {
 *         ConsoleName = "default",
 *         Location = "eastus",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/portal/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := portal.NewConsoleWithLocation(ctx, "consoleWithLocation", &portal.ConsoleWithLocationArgs{
 * 			ConsoleName: pulumi.String("default"),
 * 			Location:    pulumi.String("eastus"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.portal.ConsoleWithLocation;
 * import com.pulumi.azurenative.portal.ConsoleWithLocationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var consoleWithLocation = new ConsoleWithLocation("consoleWithLocation", ConsoleWithLocationArgs.builder()
 *             .consoleName("default")
 *             .location("eastus")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:portal:ConsoleWithLocation myresource1 /providers/Microsoft.Portal/locations/{location}/consoles/{consoleName}
 * ```
 */
public class ConsoleWithLocation internal constructor(
    override val javaResource: com.pulumi.azurenative.portal.ConsoleWithLocation,
) : KotlinCustomResource(javaResource, ConsoleWithLocationMapper) {
    /**
     * Cloud shell console properties.
     */
    public val properties: Output<ConsolePropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })
}

public object ConsoleWithLocationMapper : ResourceMapper<ConsoleWithLocation> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.portal.ConsoleWithLocation::class == javaResource::class

    override fun map(javaResource: Resource): ConsoleWithLocation = ConsoleWithLocation(
        javaResource
            as com.pulumi.azurenative.portal.ConsoleWithLocation,
    )
}

/**
 * @see [ConsoleWithLocation].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ConsoleWithLocation].
 */
public suspend fun consoleWithLocation(
    name: String,
    block: suspend ConsoleWithLocationResourceBuilder.() -> Unit,
): ConsoleWithLocation {
    val builder = ConsoleWithLocationResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ConsoleWithLocation].
 * @param name The _unique_ name of the resulting resource.
 */
public fun consoleWithLocation(name: String): ConsoleWithLocation {
    val builder = ConsoleWithLocationResourceBuilder()
    builder.name(name)
    return builder.build()
}
